@@ -9,7 +9,7 @@ import (
 )
 
 func initKeyGenSignalListener(trigger func()) {
-	sigChannel := make(chan os.Signal)
+	sigChannel := make(chan os.Signal, 1)
 	signal.Notify(sigChannel, syscall.SIGUSR1)
 	go func() {
 		for {
@@ -17,4 +17,4 @@ func initKeyGenSignalListener(trigger func()) {
 			trigger()
 		}
 	}()
-}
\ No newline at end of file
+}
